--[[
Name: oUF_AFKIcon
Description: Adds AFK Icon support to oUF Unit frames

Copyright 2008 Quaiche

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
]]


if not oUF then return end

local debugf = tekDebug and tekDebug:GetFrame("oUF_AFKIcon")
local function Debug(...) if debugf then debugf:AddMessage(string.join(", ", ...)) end end

function oUF:PLAYER_FLAGS_CHANGED(event, unitId)
	if not unitId or self.unit ~= unitId then return end

	if self.AFKIcon and UnitIsAFK(unitId) then
		Debug("Showing AFK Icon for " .. unitId)
		self.AFKIcon:Show();
	else
		Debug("Hiding AFK Icon for " .. unitId)
		self.AFKIcon:Hide()
	end
end

local function AddAFKIndicator(object)
	local texture = object.AFKIconTexture or "Interface\\Addons\\oUF_AFKIcon\\Icon.tga"
	if not object.AFKIcon then return end
	object:RegisterEvent("PLAYER_FLAGS_CHANGED")
	object.AFKIcon:SetTexture(texture)
	object:PLAYER_FLAGS_CHANGED("PLAYER_FLAGS_CHANGED", object.unit)
end

for k, object in ipairs(oUF.objects) do AddAFKIndicator(object) end
oUF:RegisterInitCallback(AddAFKIndicator)
Debug("oUF_AFKIcon Loaded")
